#define LOQUI_GENERAL_PREF_GTK_DEFAULT_COMMANDS_BROWSER_COMMAND "xdg-open %s"
#define LOQUI_GENERAL_PREF_GTK_DEFAULT_COMMANDS_NOTIFICATION_COMMAND "canberra-gtk-play --id message-new-instant"
#define LOQUI_GENERAL_PREF_GTK_DEFAULT_GENERAL_AUTO_COMMAND_MODE TRUE
#define LOQUI_GENERAL_PREF_GTK_DEFAULT_GENERAL_AUTO_SWITCH_SCROLLING TRUE
#define LOQUI_GENERAL_PREF_GTK_DEFAULT_GENERAL_AUTO_SWITCH_SCROLLING_COMMON_BUFFER FALSE
#define LOQUI_GENERAL_PREF_GTK_DEFAULT_GENERAL_CHANNEL_BUFFER_MAX_LINE_NUMBER 2000
#define LOQUI_GENERAL_PREF_GTK_DEFAULT_GENERAL_COMMAND_PREFIX "/"
#define LOQUI_GENERAL_PREF_GTK_DEFAULT_GENERAL_COMMON_BUFFER_MAX_LINE_NUMBER 500
#define LOQUI_GENERAL_PREF_GTK_DEFAULT_GENERAL_CONNECT_STARTUP FALSE
#define LOQUI_GENERAL_PREF_GTK_DEFAULT_GENERAL_NICK_LIST_SORT_TYPE 2
#define LOQUI_GENERAL_PREF_GTK_DEFAULT_GENERAL_REMARK_HISTORY_NUMBER 10
#define LOQUI_GENERAL_PREF_GTK_DEFAULT_GENERAL_SAVE_LOG FALSE
#define LOQUI_GENERAL_PREF_GTK_DEFAULT_GENERAL_SELECT_CHANNEL_JOINED TRUE
#define LOQUI_GENERAL_PREF_GTK_DEFAULT_GENERAL_TIME_FORMAT "%H:%M "
#define LOQUI_GENERAL_PREF_GTK_DEFAULT_SIZE_HPANED_POSITION 360
#define LOQUI_GENERAL_PREF_GTK_DEFAULT_SIZE_VPANED_LEFT_POSITION 200
#define LOQUI_GENERAL_PREF_GTK_DEFAULT_SIZE_VPANED_RIGHT_POSITION 200
#define LOQUI_GENERAL_PREF_GTK_DEFAULT_SIZE_SAVE_SIZE TRUE
#define LOQUI_GENERAL_PREF_GTK_DEFAULT_SIZE_WINDOW_HEIGHT 400
#define LOQUI_GENERAL_PREF_GTK_DEFAULT_SIZE_WINDOW_WIDTH 480
#define LOQUI_GENERAL_PREF_GTK_DEFAULT_TITLE_FORMAT_TITLE_FORMAT_STATUSBAR ""
#define LOQUI_GENERAL_PREF_GTK_DEFAULT_TITLE_FORMAT_TITLE_FORMAT_TITLE ""
#define LOQUI_GENERAL_PREF_GTK_DEFAULT_VISIBILITY_SHOW_CHANNELBAR TRUE
#define LOQUI_GENERAL_PREF_GTK_DEFAULT_VISIBILITY_SHOW_STATUSBAR TRUE
